@@ -1,12 +1,14 @@
-/*********************************************************************
- * Copyright (c) 2019 Red Hat, Inc.
- *
+/**
+ * Copyright (c) 2019-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- **********************************************************************/
+ *
+ * Contributors:
+ *   Red Hat, Inc. - initial API and implementation
+ */
 
 import { Command, flags } from '@oclif/command'
 import { string } from '@oclif/parser/lib/flags'
@@ -18,11 +20,11 @@ import * as semver from 'semver'
 import { ChectlContext } from '../../api/context'
 import { KubeHelper } from '../../api/kube'
 import { assumeYes, batch, cheDeployment, cheDeployVersion, cheNamespace, cheOperatorCRPatchYaml, CHE_OPERATOR_CR_PATCH_YAML_KEY, CHE_TELEMETRY, DEPLOY_VERSION_KEY, listrRenderer, skipKubeHealthzCheck } from '../../common-flags'
-import { DEFAULT_ANALYTIC_HOOK_NAME, DEFAULT_CHE_OPERATOR_IMAGE_NAME, MIN_CHE_OPERATOR_INSTALLER_VERSION, SUBSCRIPTION_NAME } from '../../constants'
+import { DEFAULT_ANALYTIC_HOOK_NAME, DEFAULT_CHE_OPERATOR_IMAGE_NAME, MIN_CHE_OPERATOR_INSTALLER_VERSION, NEXT_TAG, SUBSCRIPTION_NAME } from '../../constants'
 import { checkChectlAndCheVersionCompatibility, downloadTemplates, getPrintHighlightedMessagesTask } from '../../tasks/installers/common-tasks'
 import { InstallerTasks } from '../../tasks/installers/installer'
 import { ApiTasks } from '../../tasks/platforms/api'
-import { askForChectlUpdateIfNeeded, findWorkingNamespace, getCommandErrorMessage, getCommandSuccessMessage, getEmbeddedTemplatesDirectory, getProjectName, getProjectVersion, notifyCommandCompletedSuccessfully } from '../../util'
+import { askForChectlUpdateIfNeeded, findWorkingNamespace, getCommandSuccessMessage, getEmbeddedTemplatesDirectory, getProjectName, getProjectVersion, notifyCommandCompletedSuccessfully, wrapCommandError } from '../../util'
 
 export default class Update extends Command {
   static description = 'Update CodeReady Workspaces server.'
@@ -47,7 +49,7 @@ export default class Update extends Command {
       char: 'p',
       description: 'Type of OpenShift platform. Valid values are \"openshift\", \"crc (for CodeReady Containers)\".',
       options: ['openshift', 'crc'],
-      default: 'openshift'
+      default: 'openshift',
     }),
     chenamespace: cheNamespace,
     batch,
@@ -58,7 +60,7 @@ export default class Update extends Command {
       exclusive: [DEPLOY_VERSION_KEY],
     }),
     'che-operator-image': string({
-      description: 'Container image of the operator. This parameter is used only when the installer is the operator',
+      description: 'Container image of the operator. This parameter is used only when the installer is the operator or OLM.',
       hidden: true,
     }),
     'skip-version-check': flags.boolean({
@@ -108,7 +110,15 @@ export default class Update extends Command {
         this.error(`'--${DEPLOY_VERSION_KEY}' flag is not supported for OLM installer. 'server:update' command automatically updates to the next available version.`)
       }
 
-      if (flags.installer === 'operator' && semver.gt(MIN_CHE_OPERATOR_INSTALLER_VERSION, flags.version)) {
+      let isVersionAllowed = false
+      try {
+        isVersionAllowed = semver.gte(flags.version, MIN_CHE_OPERATOR_INSTALLER_VERSION)
+      } catch (error) {
+        // not to fail unexpectedly
+        cli.debug(`Failed to compare versions '${flags.version}' and '${MIN_CHE_OPERATOR_INSTALLER_VERSION}': ${error}`)
+      }
+
+      if (flags.installer === 'operator' && !isVersionAllowed) {
         throw new Error(this.getWrongVersionMessage(flags.version, MIN_CHE_OPERATOR_INSTALLER_VERSION))
       }
     }
@@ -118,7 +128,7 @@ export default class Update extends Command {
     // pre update tasks
     const apiTasks = new ApiTasks()
     const preUpdateTasks = new Listr([], ctx.listrOptions)
-    preUpdateTasks.add(apiTasks.testApiTasks(flags, this))
+    preUpdateTasks.add(apiTasks.testApiTasks(flags))
     preUpdateTasks.add(checkChectlAndCheVersionCompatibility(flags))
     preUpdateTasks.add(downloadTemplates(flags))
     preUpdateTasks.add(installerTasks.preUpdateTasks(flags, this))
@@ -127,7 +137,7 @@ export default class Update extends Command {
     const updateTasks = new Listr([], ctx.listrOptions)
     updateTasks.add({
       title: '↺  Updating...',
-      task: () => new Listr(installerTasks.updateTasks(flags, this))
+      task: () => new Listr(installerTasks.updateTasks(flags, this)),
     })
 
     // post update tasks
@@ -150,7 +160,7 @@ export default class Update extends Command {
 
       this.log(getCommandSuccessMessage())
     } catch (err) {
-      this.error(getCommandErrorMessage(err))
+      this.error(wrapCommandError(err))
     }
 
     notifyCommandCompletedSuccessfully()
@@ -163,12 +173,12 @@ export default class Update extends Command {
   private async checkComponentImages(flags: any): Promise<void> {
     const kubeHelper = new KubeHelper(flags)
     const cheCluster = await kubeHelper.getCheCluster(flags.chenamespace)
-    if (cheCluster.spec.server.cheImage
-      || cheCluster.spec.server.cheImageTag
-      || cheCluster.spec.server.devfileRegistryImage
-      || cheCluster.spec.database.postgresImage
-      || cheCluster.spec.server.pluginRegistryImage
-      || cheCluster.spec.auth.identityProviderImage) {
+    if (cheCluster.spec.server.cheImage ||
+      cheCluster.spec.server.cheImageTag ||
+      cheCluster.spec.server.devfileRegistryImage ||
+      cheCluster.spec.database.postgresImage ||
+      cheCluster.spec.server.pluginRegistryImage ||
+      cheCluster.spec.auth.identityProviderImage) {
       let imagesListMsg = ''
 
       const resetImagesCrPatch: { [key: string]: any } = {}
@@ -233,8 +243,8 @@ export default class Update extends Command {
       // Official images
 
       if (ctx.deployedCheOperatorImage === ctx.newCheOperatorImage) {
-        if (ctx.newCheOperatorImageTag === 'nightly') {
-          cli.info('Updating current CodeReady Workspaces nightly version to a new one.')
+        if (ctx.newCheOperatorImageTag === NEXT_TAG) {
+          cli.info(`Updating current CodeReady Workspaces ${NEXT_TAG} version to a new one.`)
           return true
         }
 
@@ -252,10 +262,10 @@ export default class Update extends Command {
         // Upgrade
 
         const currentChectlVersion = getProjectVersion()
-        if (!ctx.isNightly && (ctx.newCheOperatorImageTag === 'nightly' || semver.lt(currentChectlVersion, ctx.newCheOperatorImageTag))) {
+        if (!ctx.isDevVersion && (ctx.newCheOperatorImageTag === NEXT_TAG || semver.lt(currentChectlVersion, ctx.newCheOperatorImageTag))) {
           // Upgrade is not allowed
-          if (ctx.newCheOperatorImageTag === 'nightly') {
-            cli.warn(`Stable ${getProjectName()} cannot update stable CodeReady Workspaces to nightly version`)
+          if (ctx.newCheOperatorImageTag === NEXT_TAG) {
+            cli.warn(`Stable ${getProjectName()} cannot update stable CodeReady Workspaces to ${NEXT_TAG} version`)
           } else {
             cli.warn(`It is not possible to update CodeReady Workspaces to a newer version using the current '${currentChectlVersion}' version of crwctl. Please, update '${getProjectName()}' to a newer version using command '${getProjectName()} update' and then try again.`)
           }
@@ -263,15 +273,23 @@ export default class Update extends Command {
         }
 
         // Upgrade allowed
-        if (ctx.newCheOperatorImageTag === 'nightly') {
-          cli.info(`You are going to update CodeReady Workspaces ${ctx.deployedCheOperatorImageTag} to nightly version.`)
+        if (ctx.newCheOperatorImageTag === NEXT_TAG) {
+          cli.info(`You are going to update CodeReady Workspaces ${ctx.deployedCheOperatorImageTag} to ${NEXT_TAG} version.`)
         } else {
           cli.info(`You are going to update CodeReady Workspaces ${ctx.deployedCheOperatorImageTag} to ${ctx.newCheOperatorImageTag}`)
         }
       } else {
         // Downgrade
 
-        if (semver.gt(MIN_CHE_OPERATOR_INSTALLER_VERSION, flags.version)) {
+        let isVersionAllowed = false
+        try {
+          isVersionAllowed = semver.gte(flags.version, MIN_CHE_OPERATOR_INSTALLER_VERSION)
+        } catch (error) {
+          // not to fail unexpectedly
+          cli.debug(`Failed to compare versions '${flags.version}' and '${MIN_CHE_OPERATOR_INSTALLER_VERSION}': ${error}`)
+        }
+
+        if (!isVersionAllowed) {
           cli.info(`Given CodeReady Workspaces version ${flags.version} is too old to be downgraded to`)
           return false
         }
@@ -311,13 +329,13 @@ export default class Update extends Command {
 
   /**
    * Checks if official operator image is replaced with a newer one.
-   * Tags are allowed in format x.y.z or nightly.
-   * nightly is considered the most recent.
+   * Tags are allowed in format x.y.z or NEXT_TAG.
+   * NEXT_TAG is considered the most recent.
    * For example:
    *  (7.22.1, 7.23.0) -> true,
    *  (7.22.1, 7.20.2) -> false,
-   *  (7.22.1, nightly) -> true,
-   *  (nightly, 7.20.2) -> false
+   *  (7.22.1, NEXT_TAG) -> true,
+   *  (NEXT_TAG, 7.20.2) -> false
    * @param oldTag old official operator image tag, e.g. 7.20.1
    * @param newTag new official operator image tag e.g. 7.22.0
    * @returns true if upgrade, false if downgrade
@@ -327,11 +345,20 @@ export default class Update extends Command {
     if (oldTag === newTag) {
       throw new Error(`Tags are the same: ${newTag}`)
     }
-    // if newTag is nightly it is upgrade
-    // if oldTag is nightly it is downgrade
+
+    let isUpdate = false
+    try {
+      isUpdate = semver.gt(newTag, oldTag)
+    } catch (error) {
+      // not to fail unexpectedly
+      cli.debug(`Failed to compare versions '${newTag}' and '${oldTag}': ${error}`)
+    }
+
+    // if newTag is NEXT_TAG it is upgrade
+    // if oldTag is NEXT_TAG it is downgrade
     // otherwise just compare new and old tags
-    // Note, that semver lib doesn't handle text tags and throws an error in case nightly is provided for comparation.
-    return newTag === 'nightly' || (oldTag !== 'nightly' && semver.gt(newTag, oldTag))
+    // Note, that semver lib doesn't handle text tags and throws an error in case NEXT_TAG is provided for comparation.
+    return newTag === NEXT_TAG || (oldTag !== NEXT_TAG && isUpdate)
   }
 
   /**
