@@ -59,7 +59,7 @@ export function checkChectlAndCheVersionCompatibility(flags: any): Listr.ListrTa
       ctx.versionInfo = verInfo
       flags.version = VersionHelper.removeVPrefix(verInfo.name, true)
 
-      if (!ctx.isNightly && semver.lt(getProjectVersion(), flags.version)) {
+      if (!ctx.isDevVersion && semver.lt(getProjectVersion(), flags.version)) {
         throw new Error(`To deploy CodeReady Workspaces ${flags.version}, please update your crwctl first by running "crwctl update".`)
       }
 
@@ -141,7 +141,7 @@ export function createEclipseCheCluster(flags: any, kube: KubeHelper): Listr.Lis
       const cheClusterCR = ctx.customCR || ctx.defaultCR
       const cr = await kube.createCheCluster(cheClusterCR, flags, ctx, !ctx.customCR)
 
-      ctx.isKeycloakReady = ctx.isKeycloakReady || cr.spec.auth.externalIdentityProvider
+      ctx.isKeycloakReady = ctx.isKeycloakReady || cr.spec.auth.externalIdentityProvider || cr.spec.auth.nativeUserMode
       ctx.isPostgresReady = ctx.isPostgresReady || cr.spec.database.externalDb
       ctx.isDevfileRegistryReady = ctx.isDevfileRegistryReady || cr.spec.server.externalDevfileRegistry
       ctx.isPluginRegistryReady = ctx.isPluginRegistryReady || cr.spec.server.externalPluginRegistry
@@ -189,7 +189,7 @@ export function retrieveCheCaCertificateTask(flags: any): Listr.ListrTask {
       if (cheCaCert) {
         const targetFile = await che.saveCheCaCert(cheCaCert)
 
-        task.title = `${task.title}... done`
+        task.title = `${task.title}...OK`
         const serverStrategy = await kube.getConfigMapValue('che', flags.chenamespace, 'CHE_INFRA_KUBERNETES_SERVER__STRATEGY')
         if (serverStrategy !== 'single-host') {
           ctx.highlightedMessages.push(getMessageImportCaCertIntoBrowser(targetFile))
@@ -207,24 +207,6 @@ export function getMessageImportCaCertIntoBrowser(caCertFileLocation: string): s
   return message
 }
 
-export function getRetrieveKeycloakCredentialsTask(flags: any): Listr.ListrTask {
-  return {
-    title: 'Retrieving Keycloak admin credentials',
-    enabled: () => (flags.installer !== 'helm'),
-    task: async (ctx: any, task: any) => {
-      const che = new CheHelper(flags)
-      const [login, password] = await che.retrieveKeycloakAdminCredentials(flags.chenamespace)
-      if (login && password) {
-        ctx.identityProviderUsername = login
-        ctx.identityProviderPassword = password
-        task.title = `${task.title}...done`
-      } else {
-        task.title = `${task.title}...failed.`
-      }
-    },
-  }
-}
-
 /**
  * Prints important to user messages which are stored in ctx.highlightedMessages
  * Typically this task is the last task of a command.
