@@ -16,12 +16,12 @@ import * as execa from 'execa'
 import { DEFAULT_OLM_SUGGESTED_NAMESPACE } from '../../src/constants'
 import { isKubernetesPlatformFamily } from '../../src/util'
 
-import { E2eHelper } from './util'
+import { E2eHelper, LOGS_DIR, WORKSPACE_NAMESPACE } from './util'
 
 const helper = new E2eHelper()
 jest.setTimeout(1000000)
 
-const binChectl = `${process.cwd()}/bin/run`
+const binChectl = E2eHelper.getChectlBinaries()
 
 const NAMESPACE = DEFAULT_OLM_SUGGESTED_NAMESPACE
 
@@ -37,36 +37,36 @@ const INSTALLER_OPERATOR = 'operator'
 const INSTALLER_HELM = 'helm'
 const INSTALLER_OLM = 'olm'
 
-const DEVFILE_URL = 'https://raw.githubusercontent.com/eclipse/che-devfile-registry/master/devfiles/quarkus/devfile.yaml'
+const DEVFILE_URL = 'https://raw.githubusercontent.com/eclipse-che/che-devfile-registry/master/devfiles/go/devfile.yaml'
 
 function getDeployCommand(): string {
   let command: string
   switch (PLATFORM) {
-  case PLATFORM_OPENSHIFT:
-    if (!(INSTALLER === INSTALLER_OPERATOR || INSTALLER === INSTALLER_OLM)) {
-      throw new Error(`Unknown installer ${INSTALLER}`)
-    }
-    command = `${binChectl} server:deploy --platform=${PLATFORM} --installer=${INSTALLER} --chenamespace=${NAMESPACE} --telemetry=off --che-operator-cr-patch-yaml=test/e2e/resources/cr-patch.yaml`
-    break
+    case PLATFORM_OPENSHIFT:
+      if (!(INSTALLER === INSTALLER_OPERATOR || INSTALLER === INSTALLER_OLM)) {
+        throw new Error(`Unknown installer ${INSTALLER}`)
+      }
+      command = `${binChectl} server:deploy --platform=${PLATFORM} --installer=${INSTALLER} --chenamespace=${NAMESPACE} --telemetry=off --che-operator-cr-patch-yaml=test/e2e/resources/cr-patch.yaml`
+      break
 
-  case PLATFORM_CRC:
-  case PLATFORM_MINISHIFT:
-    if (INSTALLER !== INSTALLER_OPERATOR) {
-      throw new Error(`Unknown installer ${INSTALLER}`)
-    }
-    command = `${binChectl} server:deploy --platform=${PLATFORM} --installer=${INSTALLER} --chenamespace=${NAMESPACE} --telemetry=off --che-operator-cr-patch-yaml=test/e2e/resources/cr-patch.yaml`
-    break
+    case PLATFORM_CRC:
+    case PLATFORM_MINISHIFT:
+      if (INSTALLER !== INSTALLER_OPERATOR) {
+        throw new Error(`Unknown installer ${INSTALLER}`)
+      }
+      command = `${binChectl} server:deploy --platform=${PLATFORM} --installer=${INSTALLER} --chenamespace=${NAMESPACE} --telemetry=off --che-operator-cr-patch-yaml=test/e2e/resources/cr-patch.yaml`
+      break
 
-  case PLATFORM_MINIKUBE:
-    if (!(INSTALLER === INSTALLER_OPERATOR || INSTALLER === INSTALLER_HELM || INSTALLER === INSTALLER_OLM)) {
-      throw new Error(`Unknown installer ${INSTALLER}`)
-    }
-    const patchOption = INSTALLER === INSTALLER_HELM ? '--helm-patch-yaml=test/e2e/resources/helm-patch.yaml' : '--che-operator-cr-patch-yaml=test/e2e/resources/cr-patch.yaml'
-    command = `${binChectl} server:deploy --platform=${PLATFORM} --installer=${INSTALLER} --telemetry=off --chenamespace=${NAMESPACE} ${patchOption} --multiuser --skip-cluster-availability-check`
-    break
+    case PLATFORM_MINIKUBE:
+      if (!(INSTALLER === INSTALLER_OPERATOR || INSTALLER === INSTALLER_HELM || INSTALLER === INSTALLER_OLM)) {
+        throw new Error(`Unknown installer ${INSTALLER}`)
+      }
+      const patchOption = INSTALLER === INSTALLER_HELM ? '--helm-patch-yaml=test/e2e/resources/helm-patch.yaml' : '--che-operator-cr-patch-yaml=test/e2e/resources/cr-patch.yaml'
+      command = `${binChectl} server:deploy --platform=${PLATFORM} --installer=${INSTALLER} --telemetry=off --chenamespace=${NAMESPACE} ${patchOption} --multiuser --skip-cluster-availability-check`
+      break
 
-  default:
-    throw new Error(`Unknown platform: ${PLATFORM}`)
+    default:
+      throw new Error(`Unknown platform: ${PLATFORM}`)
   }
   return command
 }
@@ -163,15 +163,26 @@ describe('Workspace creation, list, start, inject, delete. Support stop and dele
 
       const workspaceId = await helper.getWorkspaceId()
       const { exitCode, stdout, stderr, } = await execa(binChectl, ['workspace:start', workspaceId, `-n ${NAMESPACE}`, '--telemetry=off'], { shell: true })
-
       console.log(`stdout: ${stdout}`)
       console.log(`stderr: ${stderr}`)
       expect(exitCode).equal(0)
 
-      // Sleep time to wait to workspace to be running
-      await helper.sleep(300000)
-      const workspaceStatus = await helper.getWorkspaceStatus()
-      expect(workspaceStatus).to.contain('RUNNING')
+      // Wait for workspace start 7 minutes.
+      // NOTE: Put 7 minutes because in GH actions minikube cluster we have lower memory and workspace creation can take some time
+      const desiredStatus = await helper.waitWorkspaceStatus('RUNNING', 450000)
+      expect(desiredStatus).to.be.true
+    })
+  })
+
+  describe('Get workspace logs', () => {
+    it('Testing workspace:logs command', async () => {
+      console.log('>>> Testing workspace:logs command')
+      const workspaceId = await helper.getWorkspaceId()
+      const { exitCode, stdout, stderr } = await execa(binChectl, ['workspace:logs', `--workspace ${workspaceId}`, `-n ${WORKSPACE_NAMESPACE}`, `-d ${LOGS_DIR}`, '--telemetry=off'], { shell: true })
+
+      console.log(`stdout: ${stdout}`)
+      console.log(`stderr: ${stderr}`)
+      expect(exitCode).equal(0)
     })
   })
 
@@ -246,6 +257,18 @@ describe('Workspace creation, list, start, inject, delete. Support stop and dele
     })
   })
 
+  describe('Get CodeReady Workspaces server logs', () => {
+    it('Testing server:logs command', async () => {
+      console.log('>>> Testing server:logs command')
+
+      const { exitCode, stdout, stderr } = await execa(binChectl, ['server:logs', `-d ${LOGS_DIR}`, '--telemetry=off'], { shell: true })
+
+      console.log(`stdout: ${stdout}`)
+      console.log(`stderr: ${stderr}`)
+      expect(exitCode).equal(0)
+    })
+  })
+
   describe('Stop CodeReady Workspaces server', () => {
     it('server:stop command coverage', async () => {
       console.log('>>> Testing server:stop command')
@@ -262,14 +285,19 @@ describe('Workspace creation, list, start, inject, delete. Support stop and dele
     it('server:delete command coverage', async () => {
       console.log('>>> Testing server:delete command')
 
-      // Sleep time to wait to workspace to be running
-      await helper.sleep(10 * 1000)
+      let result = await execa(binChectl, ['server:delete', `-n ${NAMESPACE}`, '--telemetry=off', '--delete-namespace', '--yes'], { shell: true })
 
-      const { exitCode, stdout, stderr } = await execa(binChectl, ['server:delete', `-n ${NAMESPACE}`, '--telemetry=off', '--delete-namespace', '--yes'], { shell: true })
+      console.log(`stdout: ${result.stdout}`)
+      console.log(`stderr: ${result.stderr}`)
+      expect(result.exitCode).equal(0)
 
-      console.log(`stdout: ${stdout}`)
-      console.log(`stderr: ${stderr}`)
-      expect(exitCode).equal(0)
+      // run deletion second time to ensure that
+      // server:delete does not fail if resource is absent
+      result = await execa(binChectl, ['server:delete', `-n ${NAMESPACE}`, '--telemetry=off', '--delete-namespace', '--yes'], { shell: true })
+
+      console.log(`stdout: ${result.stdout}`)
+      console.log(`stderr: ${result.stderr}`)
+      expect(result.exitCode).equal(0)
     })
   })
 })
